==> amity-sdk-7.12.1-sources.jar: main/com/amity/socialcloud/sdk/api/social/post/query/AmityUserPostQuery.kt <==
package com.amity.socialcloud.sdk.api.social.post.query

import androidx.paging.PagingData
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.ekoapp.ekosdk.internal.usecase.post.GetUserPostPagingDataUseCase
import io.reactivex.rxjava3.core.Flowable

class AmityUserPostQuery internal constructor(
    private val userId: String,
    private val sortOption: AmityUserFeedSortOption,
    private val isDeleted: Boolean?,
    @Deprecated("Use dataTypes instead")
    private val postTypes: List<AmityPost.DataType>,
    private val dataTypes: List<AmityPost.DataType> = postTypes,
    private val includeMixedStructure: Boolean
) {

    /**
     * Queries for User feed.
     * @return Flowable<PagingData<AmityPost>>.
     */
    fun query(): Flowable<PagingData<AmityPost>> {
        return GetUserPostPagingDataUseCase().execute(
            userId = userId,
            sortOption = sortOption,
            isDeleted = isDeleted,
            dataTypes = dataTypes.ifEmpty { postTypes },
            includeMixedStructure = includeMixedStructure
        )
    }


    class Builder internal constructor(private val userId: String) {

        private var sortOption: AmityUserFeedSortOption = AmityUserFeedSortOption.LAST_CREATED
        private var isDeleted: Boolean? = null
        private var postTypes: List<AmityPost.DataType> = listOf()
        private var dataTypes: List<AmityPost.DataType> = listOf()
        private var includeMixedStructure: Boolean = false
        /**
         * Specifies [sortOption] param.
         * When [sortOption] is AmityUserFeedSortOption.FIRST_CREATED, posts will be sorted by createdAt property ASC.
         * When [sortOption] is AmityUserFeedSortOption.LAST_CREATED, posts will be sorted by createdAt property DESC.
         * The default value of [sortOption] is AmityUserFeedSortOption.LAST_CREATED.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun sortBy(sortOption: AmityUserFeedSortOption): Builder {
            return apply { this.sortOption = sortOption }
        }

        /**
         * Specifies [includeDeleted] param.
         * When [includeDeleted] is true, the result will include soft-deleted posts.
         * When [includeDeleted] is false, the result will exclude soft-deleted posts.
         * The default value of [includeDeleted] is true.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun includeDeleted(includeDeleted: Boolean): Builder {
            return apply {
                this.isDeleted = if(includeDeleted) null else false
            }
        }

        /**
         * Specifies [postTypes] to filter matching dataType.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        @Deprecated("Use types(dataTypes) instead")
        fun types(postTypes: List<AmityPost.DataType>): Builder {
            return apply {
                this.postTypes = postTypes
                this.dataTypes = postTypes
            }
        }

        /**
         * Specifies [dataTypes] to filter matching dataType.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun dataTypes(dataTypes: List<AmityPost.DataType>): Builder {
            return apply { this.dataTypes = dataTypes }
        }

        fun includeMixedStructure(includeMixedStructure: Boolean): Builder {
            return apply { this.includeMixedStructure = includeMixedStructure }
        }

        /**
         * Instantiates AmityUserPostQuery with built params.
         * @return new instance of AmityUserPostQuery.
         */
        fun build(): AmityUserPostQuery {
            return AmityUserPostQuery(
                userId = userId,
                sortOption = sortOption,
                isDeleted = isDeleted,
                postTypes = postTypes,
                dataTypes = dataTypes,
                includeMixedStructure = includeMixedStructure
            )
        }
    }

}

==> amity-sdk-7.15.0-sources.jar: main/com/amity/socialcloud/sdk/api/social/post/query/AmityUserPostQuery.kt <==
package com.amity.socialcloud.sdk.api.social.post.query

import androidx.paging.PagingData
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.ekoapp.ekosdk.internal.usecase.post.GetUserPostPagingDataUseCase
import io.reactivex.rxjava3.core.Flowable

class AmityUserPostQuery internal constructor(
    private val userId: String,
    private val sortOption: AmityUserFeedSortOption,
    private val isDeleted: Boolean?,
    @Deprecated("Use dataTypes instead")
    private val postTypes: List<AmityPost.DataType>,
    private val dataTypes: List<AmityPost.DataType> = postTypes,
    private val tags: List<String>,
    private val includeMixedStructure: Boolean
) {

    /**
     * Queries for User feed.
     * @return Flowable<PagingData<AmityPost>>.
     */
    fun query(): Flowable<PagingData<AmityPost>> {
        return GetUserPostPagingDataUseCase().execute(
            userId = userId,
            sortOption = sortOption,
            isDeleted = isDeleted,
            dataTypes = dataTypes.ifEmpty { postTypes },
            tags = tags,
            includeMixedStructure = includeMixedStructure
        )
    }


    class Builder internal constructor(private val userId: String) {

        private var sortOption: AmityUserFeedSortOption = AmityUserFeedSortOption.LAST_CREATED
        private var isDeleted: Boolean? = null
        private var postTypes: List<AmityPost.DataType> = listOf()
        private var dataTypes: List<AmityPost.DataType> = listOf()
        private var tags: List<String> = listOf()
        private var includeMixedStructure: Boolean = false
        /**
         * Specifies [sortOption] param.
         * When [sortOption] is AmityUserFeedSortOption.FIRST_CREATED, posts will be sorted by createdAt property ASC.
         * When [sortOption] is AmityUserFeedSortOption.LAST_CREATED, posts will be sorted by createdAt property DESC.
         * The default value of [sortOption] is AmityUserFeedSortOption.LAST_CREATED.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun sortBy(sortOption: AmityUserFeedSortOption): Builder {
            return apply { this.sortOption = sortOption }
        }

        /**
         * Specifies [includeDeleted] param.
         * When [includeDeleted] is true, the result will include soft-deleted posts.
         * When [includeDeleted] is false, the result will exclude soft-deleted posts.
         * The default value of [includeDeleted] is true.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun includeDeleted(includeDeleted: Boolean): Builder {
            return apply {
                this.isDeleted = if(includeDeleted) null else false
            }
        }

        /**
         * Specifies [postTypes] to filter matching dataType.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        @Deprecated("Use types(dataTypes) instead")
        fun types(postTypes: List<AmityPost.DataType>): Builder {
            return apply {
                this.postTypes = postTypes
                this.dataTypes = postTypes
            }
        }

        /**
         * Specifies [dataTypes] to filter matching dataType.
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun dataTypes(dataTypes: List<AmityPost.DataType>): Builder {
            return apply { this.dataTypes = dataTypes }
        }

        /**
         * Specifies [tags] to filter posts by tags.
         * @param tags Array of tag strings to filter posts (max 5)
         * @return the same AmityUserPostQuery.Builder instance.
         */
        fun tags(tags: List<String>): Builder {
            return apply { this.tags = tags.take(5) }
        }

        fun includeMixedStructure(includeMixedStructure: Boolean): Builder {
            return apply { this.includeMixedStructure = includeMixedStructure }
        }

        /**
         * Instantiates AmityUserPostQuery with built params.
         * @return new instance of AmityUserPostQuery.
         */
        fun build(): AmityUserPostQuery {
            return AmityUserPostQuery(
                userId = userId,
                sortOption = sortOption,
                isDeleted = isDeleted,
                postTypes = postTypes,
                dataTypes = dataTypes,
                tags = tags,
                includeMixedStructure = includeMixedStructure
            )
        }
    }

}
